{
  config,
  extraInfo,
  pkgs,
  ...
}:
{
  services.nginx.virtualHosts.${extraInfo.nextcloudURI} = {
    enableACME = true;
    forceSSL = true;
  };

  services.nextcloud = {
    enable = true;
    package = pkgs.nextcloud30;
    datadir = "/srv/nextcloud";
    https = true;
    hostName = extraInfo.nextcloudURI;

    maxUploadSize = "50G";

    extraAppsEnable = true;
    appstoreEnable = false;
    extraApps = {
      inherit (config.services.nextcloud.package.packages.apps)
        calendar
        cospend
        twofactor_webauthn
        deck
        user_oidc
        ;
    };

    database.createLocally = true;
    configureRedis = true;

    settings = {
      default_phone_region = "FR";
    };

    config = {
      dbtype = "pgsql";

      adminuser = "dala";
      adminpassFile = config.age.secrets.nextcloudAdminPassword.path;
    };

    caching = {
      redis = true;
      memcached = true;
      apcu = true;
    };
  };
}
