{
  description = "Dala's unified NixOS configuration";
  inputs = {
    # As we have machine using the unstable channel, and other machines using the stable one,
    # we import both, and we will select for each machine which one to use.
    nixpkgs-unstable.url = "github:NixOS/nixpkgs/nixos-unstable";
    nixpkgs-stable.url = "github:NixOS/nixpkgs/nixos-24.11";
    flake-utils.url = "github:numtide/flake-utils";

    # Home-manager isn't used for anything except my workstations, which all use the unstable channel.
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs-unstable";
    };

    agenix.url = "github:ryantm/agenix";

    # Use Lix instead of Nix
    lix.url = "https://git.lix.systems/lix-project/nixos-module/archive/2.92.0.tar.gz";

    lanzaboote.url = "github:nix-community/lanzaboote";

    dalaran-fr.url = "https://git.dalaran.fr/dala/dalaran.fr/archive/main.tar.gz";

    extra-config.url = "git+ssh://forgejo@git.dalaran.fr/dala/nixos-config-extra.git";
  };

  outputs =
    {
      self,
      nixpkgs-unstable,
      nixpkgs-stable,
      home-manager,
      agenix,
      flake-utils,
      extra-config,
      lix,
      lanzaboote,
      dalaran-fr,
    }:
    let
      machines = import ./machines.nix;
      my = import ./modules;
      lixModule = lix.nixosModules.lixFromNixpkgs;
      nixpkgsVersions = {
        stable = nixpkgs-stable;
        unstable = nixpkgs-unstable;
      };
      machinesNodes = builtins.mapAttrs (
        name: config:
        { ... }:
        {
          imports = [
            lixModule
            ./configurations/${name}
            (if config.enableHomeManager then home-manager.nixosModules.home-manager else { })
            (if (config.system == "x86_64-linux") then lanzaboote.nixosModules.lanzaboote else { })
          ];

          deployment.allowLocalDeployment = config.localDeployment;

          networking.hostName = name;
          system.stateVersion = config.stateVersion;
        }
      ) machines;
      buildOptionnalSpecialArgsForMachine = config: {
        machineProps = config;
      };
    in
    {
      colmena = {
        meta = {
          name = "dala's infrastructure";

          # Here we have to set this value because colmena needs it, but it will be overriden on all hosts
          # by the nodeNixpkgs attribute
          nixpkgs = import nixpkgsVersions.stable { system = "x86_64-linux"; };

          nodeNixpkgs = builtins.mapAttrs (
            name: config:
            import nixpkgsVersions.${config.nixpkgs} {
              system = config.system;
              overlays = [
                dalaran-fr.overlays.default
              ];
            }
          ) machines;

          nodeSpecialArgs = builtins.mapAttrs (
            name: config:
            { extraInfo = extra-config.extraSecrets; } // (buildOptionnalSpecialArgsForMachine config)
          ) machines;
        };

        defaults =
          { ... }:
          {
            imports = [
              agenix.nixosModules.default
              my.modules
            ];
          };
      } // machinesNodes;

      formatter = builtins.listToAttrs (
        map (
          system:
          let
            pkgs = import nixpkgsVersions.unstable { inherit system; };
          in
          {
            name = system;
            value = pkgs.nixfmt-rfc-style;
          }
        ) flake-utils.lib.defaultSystems
      );

      devShells = builtins.listToAttrs (
        map (
          system:
          let
            pkgs = import nixpkgsVersions.unstable { inherit system; };
          in
          {
            name = system;
            value.default = pkgs.mkShell {
              name = "Nix development environment";

              packages = with pkgs; [
                colmena
                nixfmt-rfc-style
                nil
                agenix.packages.${system}.default
              ];
            };
          }
        ) flake-utils.lib.defaultSystems
      );
    };
}
