{ pkgs, lib, ... }:
with lib;
let
  multimediaPackages = with pkgs; [
    qpwgraph
    feh
    gimp
    vlc
  ];

  soundPackages = with pkgs; [
    pavucontrol
    pamixer
  ];

  yubikeyTools = with pkgs; [
    yubikey-personalization
    yubico-pam
    yubikey-manager
  ];
in
{
  imports = [
    ./desktop
    ./development
    ./fish.nix
    ./ssh.nix
    ./communication.nix
    ./mail.nix
    ./helix.nix
    ./games.nix
    ./libreoffice.nix
    ./rustdesk.nix
  ];

  config = {

    fonts.fontconfig.enable = true;

    home.packages =
      with pkgs;
      [
        htop
        librewolf
        autojump
        nextcloud-client
        keepassxc
        ranger
        tldr
        zathura
        lazygit
        easyeffects
      ]
      ++ multimediaPackages
      ++ soundPackages
      ++ yubikeyTools;

    # XDG-Mime configuration
    xdg.mime.enable = true;
    xdg.mimeApps.enable = true;
    xdg.mimeApps.associations.added = {
      "x-scheme-handler/https" = "firefox.desktop";
      "x-scheme-handler/http" = "firefox.desktop";
    };
    xdg.mimeApps.defaultApplications = {
      "x-scheme-handler/https" = "firefox.desktop";
      "x-scheme-handler/http" = "firefox.desktop";
      "text/html" = "firefox.desktop";
    };
  };
}
